==> haskell-skylighting-format-blaze-html-0.1.1.3-138-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-GpCLmLOOVFp2GD8SvOgwKO

key:
    skylighting-format-blaze-html-0.1.1.3-GpCLmLOOVFp2GD8SvOgwKO

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  e38012cf6630bf236a4d116d8cf06866
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-GpCLmLOOVFp2GD8SvOgwKO

depends:
    base-4.18.2.1 blaze-html-0.9.2.0-1747vvTiFgL3mVhTAPflSj
    containers-0.6.7 skylighting-core-0.14.3-7mhH9r2pWCw3xU0g23Jkur
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-blaze-html-0.1.1.3-139-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-blaze-html
version:              0.1.1.3
visibility:           public
id:
    skylighting-format-blaze-html-0.1.1.3-5vL2xZYU7MO5NzGplp7EpS

key:
    skylighting-format-blaze-html-0.1.1.3-5vL2xZYU7MO5NzGplp7EpS

license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             HTML formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as HTML.

category:             Text
abi:                  1fa60591698f937ed9620c4c375bf85a
exposed:              True
exposed-modules:      Skylighting.Format.HTML
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-blaze-html-0.1.1.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-blaze-html
hs-libraries:
    HSskylighting-format-blaze-html-0.1.1.3-5vL2xZYU7MO5NzGplp7EpS

depends:
    base-4.18.2.1 blaze-html-0.9.2.0-5pCa6Zd2ytCBxKPCiAVcIx
    containers-0.6.7 skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-blaze-html/html/skylighting-format-blaze-html.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-blaze-html/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
